@@ -1,4 +1,4 @@
-! WHIZARD 2.2.1 June 3 2014
+! WHIZARD 2.2.2 July 6 2014
 ! 
 ! Copyright (C) 1999-2014 by 
 !     Wolfgang Kilian <kilian@physik.uni-siegen.de>
@@ -763,6 +763,9 @@ contains
        case (:-1)
           hpol%polarized = .true.
           hpol%obj = new_polarization (real (pi, c_double), 0._c_double)
+       case (0)
+          hpol%polarized = .true.
+          hpol%obj = new_polarization (real (pi/2, c_double), 0._c_double)
        end select
     end if
   end subroutine hepmc_polarization_init_hel
@@ -777,6 +780,9 @@ contains
     case (:-1)
        hpol%polarized = .true.
        hpol%obj = new_polarization (real (pi, c_double), 0._c_double)
+    case (0)
+       hpol%polarized = .true.
+       hpol%obj = new_polarization (real (pi/2, c_double), 0._c_double)
     end select
   end subroutine hepmc_polarization_init_int
 
